% (c) Broadbent, Di Pace, Drechsel, Harrison and Tenreyro (2018)
% 09 September 2021
% This code estimates the baseline model featuring a debt elastic premium.
% The shocks contained are sectoral temporary and permanent productivity
% innovations (gatshk, ganshk, atshk, anshk), an exchange rate shock (omgshk),
% risk-premium shock (nushk), foreign interest rate shock (mushk) and other 
% NT expenditure shock (sshk).

close all;
%-------------------------------------------------------------------------
% 0. Housekeeping (close all graphic windows)
%-------------------------------------------------------------------------
% 1. Declaration of Variables and Shocks
%-------------------------------------------------------------------------
% 1.1 Endogenous Variables
%-------------------------------------------------------------------------
   
var lambda $\lambda$ (long_name='marginal utility of consumption in $T$')
    c (long_name='consumption')
    ct $c_{T}$ (long_name='consumption in $T$')
    cn $c_{N}$ (long_name='consumption in $N$')
    kn $k_{N}$ (long_name='$T$ capital')
    kt $k_{T}$ (long_name='$N$ capital')
    rkt $r^{k}_{T}$ (long_name='rental rate in $T$')
    rkn $r^{k}_{N}$ (long_name='rental rate in $T$')
    yt $y_{T}$ (long_name='$T$ output')
    yn $y_{N}$ (long_name='$N$ output')
    y (long_name='aggregate output')
    p (long_name='RER')
    n (long_name='total hours')
    nn $n_{N}$ (long_name='hours in $N$')
    nt $n_{T}$ (long_name='hours in $T$')
    wn $w_{N}$ (long_name='wages in $N$')
    wt $w_{T}$ (long_name='wages in $T$')
    bf $b_{F}$ (long_name='NFA position')
    rf $r_{F}$ (long_name='foreing interest rate')
    rh $r_{H}$ (long_name='home interest rate')
    tb $tb$ (long_name='trade balance')
    iv $i$ (long_name='investment')
    pc (long_name='Consumption price in terms of tradables$')
    gan $g_{N}$ (long_name='TFP growth rate in $N$') 
    gat $g_{T}$ (long_name='TFP growth rate in $T$')
    shyty $\bar{y}_{T}\bar{Y}$ (long_name='Ouput in T over Aggregate Output');

%-------------------------------------------------------------------------
% 1.2 Parameters 
%-------------------------------------------------------------------------
parameters cbeta $\beta$ (long_name='discount factor')
           csigma $\sigma$ (long_name='elasticity of substitution between $T$ and $N$')
           cgamma $\gamma$ (long_name='inter-termporal elasticity of substitution')
           comegat $\omega$ (long_name='Frisch elasticity parameter')
           comegan $\omega$ (long_name='Frisch elasticity parameter')
           czeta $\zeta$ (long_name='share of absorption in T')
           cthetat $\theta_{T}$ (long_name='disutility parameter in $T$')
           cthetan $\theta_{N}$ (long_name='disutility parameter in $N$')
           cphit $\phi_{T}$ (long_name='capital adjustment cost in $T$')
           cphin $\phi_{N}$ (long_name='capital adjustment cost in $N$')
           calpt $\alpha_{T}$ (long_name='capital share in $T$')
           calpn $\alpha_{N}$ (long_name='capital share in $N$')
           calphton $\alpha_{N}$ (long_name='Ratio of LS in T to N')
           crf $\bar{r}_{F}$ (long_name='SS foreign interest rate')
           cpsi $\psi$ (long_name='foreing interest rate debt elasticity')
           cgyn
           cgat $\bar{g}_{T}$ (long_name='SS growth rate of Output in $T$')
           cgan $\bar{g}_{N}$ (long_name='SS growth rate of Output in $N$')
           cgazn $\bar{g}_{N}$ (long_name='SS growth rate of TFP in $N$')
           cgazt $\bar{g}_{N}$ (long_name='SS growth rate of TFP in $N$')
           can $\bar{g}_{N}$ (long_name='SS productivity level in $N$')
           cdeltat $\delta_{T}$ (long_name='depreciation rate of capital in $T$')
           cdeltan $\delta_{N}$ (long_name='depreciation rate of capital in $N$')
           cbf $\bar{b}^{*}$ (long_name='net foreign asset position')
           ccoy
           cnt $\bar{n_{T}}$ (long_name='steady state value of hours in T')
           cnn $\bar{n_{N}}$ (long_name='steady state value of hours in N')
           ctby $\bar{i}/\bar{y}$ (long_name='TB to Output Ratio')
           cioy $\bar{i}/\bar{y}$ (long_name='Inv. to Output Ratio')
           cgoy $\bar{g}/\bar{y}$ (long_name='Gov. to Output Ratio')
           rer_ss $\bar{RER}$ (long_name='SS value of RER in consumption terms');  

%-------------------------------------------------------------------------
% 1.3 Shocks
%-------------------------------------------------------------------------
var gazn $g_{N}$ (long_name='TFP growth rate in $N$') 
    gazt $g_{T}$ (long_name='TFP growth rate in $T$')
    an $a_{N}$ (long_name='TFP in $N$')
    at $a_{T}$ (long_name='TFP in $T$')
    s (long_name='government expenditure')
    mu $\mu$ (long_name='foreing interest rate process')
    eps $\epsilon$ (long_name='labour supply process')
    nu $\nu$ (long_name='discount factor process');
    
varexo ganshk $\varepsilon^{N}_{g}$ (long_name='TFP growth shock in $N$')
       gatshk $\varepsilon^{T}_{g}$ (long_name='TFP growth shock in $T$')
       sshk $\varepsilon_{s}$ (long_name='government expenditure shock')
       nushk $\varepsilon_{\nu}$ (long_name='discount factor shock')
       mushk $\varepsilon_{\mu}$ (long_name='foreign interest rate shock')
       anshk $\varepsilon^{a}_{N}$ (long_name='temporary TFP shock in $N$')
       atshk $\varepsilon^{a}_{T}$ (long_name='temporary TFP shock in $T$')
       epsshk $\varepsilon_{\epsilon}$ (long_name='temporary TFP shock in $T$');
       
        
%-------------------------------------------------------------------------
% 1.4 Percentage deviations from ss
%-------------------------------------------------------------------------
%var logP logY logC logI;
%-------------------------------------------------------------------------
% 1.5 Observables
%-------------------------------------------------------------------------
var rer yt_nt yn_nn TB_Y NN NT N DlogYY DlogQ DlogP DlogPA logQ DlogYN_NN DlogYT_NT I_Y C_Y Robs1 Robs2; 
%-------------------------------------------------------------------------
% 1.5 Shock Parameters
%-------------------------------------------------------------------------
    
parameters cvsgan $\varsigma_{g_{N}}$ 
           cvsgat $\varsigma_{g_{T}}$
           cvsat $\varsigma_{a_{T}}$
           cvsan $\varsigma_{a_{N}}$
           cvsgv $\varsigma_{s}$
           cvsmu $\varsigma_{\mu}$
           cvseps $\varsigma_{\epsilon}$
           cvsnu $\varsigma_{\nu}$
           cvrgan $\varrho^{g}_{N}$
           cvrgat $\varrho^{g}_{T}$
           cvran $\varrho^{a}_{N}$
           cvrat $\varrho^{g}_{T}$
           cvrgv $\varrho_{s}$
           cvrmu $\varrho_{\mu}$
           cvreps $\varrho_{\epsilon}$
           cvrnu $\varrho_{\nu}$; 
       
%-------------------------------------------------------------------------
% 2. Parameters
%-------------------------------------------------------------------------
% 2.1 Data Calibrated
%-------------------------------------------------------------------------
crf=0.01;                           % CHECK THIS CALIBRATION
cgamma=2;                           % calibrated froSilvana and Thomas (2018)
cgat=1.004;                         % from GVA T output (adjusted for full sample given aggregate average)
cgan=1.003;                         % from GVA N output (adjusted for full sample given aggregate average)
cnt=1.1;                            % Half of the time working in T sector
cnn=cnt*(1-0.42)/0.42;              % Half of the time working in T sector
cbeta=1/((1+crf)*cgat^(-cgamma));   % Subjective discount factor (calculated using world interest rate)
calphton=1.3;                       % Ratio of labour shares (T over N)
cdeltat=0.006;                      % lower than COMPASS. The depreciation rates are set to match I/Y
cdeltan=0.006;                      % lower than COMPASS. The depreciation rates are set to match I/Y
cioy=0.192;                         % C/GDP (calibrated from 1987Q3 and 2016Q2)
ccoy=0.644;                         % I/GDP (calibrated from 1987Q3 and 2016Q2)
ctby=0;                             % TB/GDP (calibrated from 1987Q3 and 2016Q2)
czeta=0.59;                         % Set to match 0.52 YT/T share
cpsi=0.1/20000;                     % calibrated to be small unlike in emerging market economies


%% overwritten parameters
calpt=1-0.683870561;                % calibrated to the data
calpn=1-0.754519035;                % calibrated to the data
cgyn=0.30;
cbf=0.75;                           
cthetan=1; 
cthetat=1.1; 
rer_ss=1;
can=1;
cgazn=1;
cgazt=1;
cgoy=0.18434;                 % Investment over GDP ratio (calibrated from 1987Q3 and 2016Q2)

%-------------------------------------------------------------------------
% 2.2.1 Estimated
%-------------------------------------------------------------------------
csigma=0.5;                       % The elasticity of substitution should be around to 0.75
comegat=1.6;                         % calibrated based on paper!!!
comegan=1.6;                         % calibrated based on paper!!!
cphit=4;
cphin=4;      

%-------------------------------------------------------------------------
% 2.2.2 Shocks
%-------------------------------------------------------------------------
cvsgan=0.01;
cvsgat=0.01;
cvsat=0.01; 
cvsan=0.01; 
cvsgv=0.01; 
cvsmu=0.01;
cvseps=0.01;
cvsnu=0.01;
cvrgan=0.9;
cvrgat=0.9;
cvran=0.9;
cvrat=0.9;
cvrgv=0.9;
cvrmu=0.9;
cvreps=0.9;
cvrnu=0.9;

%-------------------------------------------------------------------------
% 2.2.3 Estimated Outside the Model
%-------------------------------------------------------------------------
%-------------------------------------------------------------------------
% 3. Model
%-------------------------------------------------------------------------
options_.Tex=1;
model;
%-------------------------------------------------------------------------    
% 3.1 Households
%-------------------------------------------------------------------------
    [name='Consumption aggregator', eq='#1']
    c=(czeta^(1+csigma)*ct^(-csigma)+(1-czeta)^(1+csigma)*cn^(-csigma))^(1/(-csigma));           
    [name='Marginal utility of $T$ consumption', eq='#3']
    (c-eps*(cthetan/comegan*nn^comegan+cthetat/comegat*nt^comegat))^(-cgamma)
           *czeta^(1+csigma)*(ct/c)^(-csigma-1)=lambda;                                      
    [name='Marginal utility of $N$ consumption', eq='#4']
    (c-eps*(cthetan/comegan*nn^comegan+cthetat/comegat*nt^comegat))^(-cgamma)
            *(1-czeta)^(1+csigma)*(cn/c)^(-csigma-1)=p*lambda;                               
    [name='Labour optimality condition in $N$', eq='#5']
    (c-eps*(cthetan/comegan*nn^comegan+cthetat/comegat*nt^comegat))^(-cgamma)
    *cthetan*nn^(comegan-1)*eps=wn*lambda;                                                      
    [name='Labour optimality condition in $T$', eq='#6']
    (c-eps*(cthetan/comegan*nn^comegan+cthetat/comegat*nt^comegat))^(-cgamma)
    *cthetat*nt^(comegat-1)*eps=wt*lambda;                                                   
    [name='interest rate on foreign bonds', eq='#9']
    rf=crf+cpsi*(exp(bf-cbf)-1)+(exp(mu-1)-1);                                                  
    [name='Euler equation in $T$ Bonds', eq='#10']
    lambda=cbeta*(1+rf)*gat^(-cgamma)*lambda(+1)*(nu(+1)/nu);
    [name='Euler equation in $N$ Bonds', eq='#11']
    lambda*pc=cbeta*(1+rh)*gat^(-cgamma)*lambda(+1)*pc(+1)*(nu(+1)/nu);
    [name='Euler equation in $T$ capital', eq='#12']                                                
    lambda*pc*(1+cphit*(kt/kt(-1)*gat-cgat))=cbeta*gat^(-cgamma)*pc(+1)*lambda(+1)
           *(nu(+1)/nu)*(1/pc(+1)*rkt(+1)+(1-cdeltat)
           + cphit*(kt(+1)/kt*gat(+1)-cgat)*(kt(+1)/kt)*gat(+1) 
           - cphit/2*(kt(+1)/kt*gat(+1)-cgat)^2);
    [name='Euler equation in $N$ capital', eq='#13']                                                
    lambda*pc*(1+cphin*(kn/kn(-1)*gat-cgat))=cbeta*gat^(-cgamma)*pc(+1)*lambda(+1)
            *(nu(+1)/nu)*(1/pc(+1)*rkn(+1)+(1-cdeltan)
            + cphin*(kn(+1)/kn*gat(+1)-cgat)*(kn(+1)/kn)*gat(+1) 
            - cphin/2*(kn(+1)/kn*gat(+1)-cgat)^2);                                              
%-------------------------------------------------------------------------
% 3.2 Firms
%-------------------------------------------------------------------------
    [name='Production function $T$', eq='#14']
    yt=at*kt(-1)^calpt*(gazt*nt)^(1-calpt);                                                      
    [name='Production function $N$', eq='#15']
    yn=an*kn(-1)^calpn*(gazn*nn)^(1-calpn);                                                      
    [name='Marginal product of capital in $T$', eq='#16']
    rkt=calpt*at*kt(-1)^(calpt-1)*(gazt*nt)^(1-calpt);                                           
    [name='Marginal product of capital in $N$', eq='#17']
    rkn=p*calpn*an*kn(-1)^(calpn-1)*(gazn*nn)^(1-calpn);                                           
    [name='Marginal product of labour in $T$', eq='#18']
    wt=(1-calpt)*at*gazt^(1-calpt)*kt(-1)^calpt*nt^(-calpt);                                     
    [name='Marginal product of labour in $N$', eq='#19']
    wn=p*(1-calpn)*an*gazn^(1-calpn)*kn(-1)^calpn*nn^(-calpn);                                   
    
%-------------------------------------------------------------------------
% 3.2 Resource Constraints and Definitions
%-------------------------------------------------------------------------
    [name='Resource constraint in $T$', eq='#20']
    yt=ct+czeta*iv*(pc)^(1/(1+csigma))+tb+pc*cphit/2*(kt/kt(-1)*gat-cgat)^2*kt(-1);                                                                                
    [name='Resource constraint in $N$', eq='#21']
    yn*(1-cgyn*s)=cn+(1-czeta)*iv*(pc/p)^(1/(1+csigma))+pc/(p)*cphin/2*(kn/kn(-1)*gat-cgat)^2*kn(-1);
    [name='Growth rate in T', eq='#22']
    gat=gazt;                                                                                    
    [name='Growth rate in N', eq='#23']
    gan=gat^calpn*gazn^(1-calpn);                                                                
    [name='Net foreign asset position', eq='#24']
    bf(-1)-bf/((1+rf))*gat=tb;
    [name='Definition of output', eq='#25']
    y=yt+p*yn;                                                                                   
    [name='Definition of investment', eq='#28']
    iv=(kt*gat-(1-cdeltat)*kt(-1)+kn*gat-(1-cdeltan)*kn(-1));                             
    [name='Consumption Price in terms of T goods', eq='#29']
    pc=(czeta+(1-czeta)*p^(csigma/(1+csigma)))^((1+csigma)/(csigma));                        
%-------------------------------------------------------------------------
% 3.10 Shocks
%-------------------------------------------------------------------------   
% 3.10.1 Structural Shocks
%-------------------------------------------------------------------------
    [name='Government expenditure shock', eq='#31']
    s=s(-1)^cvrgv*exp(cvsgv*sshk);
    [name='Foreign interest rate shock', eq='#32']
    mu=mu(-1)^cvrmu*exp(cvsmu*mushk);
    [name='Growth rate shock in $N$', eq='#33']
    gazn=cgazn^(1-cvrgan)*gazn(-1)^cvrgan*exp(cvsgan*ganshk);
    [name='Growth rate shock in $T$ ', eq='#34']
    gazt=cgazt^(1-cvrgat)*gazt(-1)^cvrgat*exp(cvsgat*gatshk);
    [name='Temporary TFP shock in $N$', eq='#35']
    (an/can)=(an(-1)/can)^cvran*exp(cvsan*anshk);
    [name='Temporary TFP shock in $T$', eq='#36']
    at=at(-1)^cvrat*exp(cvsat*atshk);
    [name='Discount fact shock', eq='#38']
    nu=nu(-1)^cvrnu*exp(cvsnu*nushk);
    [name='Aggregate labour supply shock', eq='#39']
    eps=eps(-1)^cvreps*exp(cvseps*epsshk);

%-------------------------------------------------------------------------
% 3.11 Var expressed in %dev. from SS
%-------------------------------------------------------------------------       
%    [name='RER in % dev. from ss', eq='#43']  
%    logP=log(p);
%    [name='output in % dev. from ss', eq='#44']  
%    logY=log(y);
%    [name='investment in % dev. from ss', eq='#45']  
%    logI=log(iv);
%    [name='consumption in % dev. from ss', eq='#46']  
%    logC=log(c);
%-------------------------------------------------------------------------
% 3.12 Observables
%-------------------------------------------------------------------------       
    [name='Definition of hours', eq='#47']
    n=nt+nn;
    [name='Definition of rer', eq='#48']
    rer=pc;                                                                                  
    [name='Definition of labour productivity in $T$', eq='#49']
    yt_nt=yt/nt;
    [name='Definition of labour productivity in $N$', eq='#50']                                 
    yn_nn=yn/nn;
    [name='growth rate of RER', eq='#54']
    DlogQ=log(rer/rer(-1));
    [name='% dev of RER', eq='#55']
    logQ=log(rer/rer_ss);
    [name='% Obervable P', eq='#56']
    DlogP=log(p/p(-1)*gat(-1)/gan(-1));
    [name='% Obervable P', eq='#57']
    DlogPA=DlogP+DlogP(-1)+DlogP(-2)+DlogP(-3);
    [name='% dev of hours in N', eq='#58']
    NN=log(nn/cnn);
    [name='% dev of hours in T', eq='#59']
    NT=log(nt/cnt);
    [name='% dev of aggregate hours', eq='#59']
    N=log(n/(cnt+cnn));
    [name='labour productivity growth rate in T', eq='#64']
    DlogYT_NT=log(gat(-1)*yt_nt/yt_nt(-1));
    [name='labour productivity growth rate in N', eq='#65']
    DlogYN_NN=log(gan(-1)*yn_nn/yn_nn(-1));
    [name='labour productivity growth rate in N', eq='#65']
    shyty=(yt/y+yt(-1)/y(-1)+yt(-2)/y(-2)+yt(-3)/y(-3))/4;
    [name='Aggregate Growth Rate', eq='#66']
    DlogYY=log(shyty*(yt/yt(-1))*gat(-1)+(1-shyty)*(yn/yn(-1))*gan(-1));
    [name='Trade Balance over GDP (in terms of Tradables)', eq='#67']
    TB_Y=tb/y;
    [name='Investment over GDP (in terms of Tradables)', eq='#68']
    I_Y=pc*iv/y;
    [name='Consumption over GDP (in terms of Tradables)', eq='#69']
    C_Y=pc*c/y;
    [name='Foreing Interest Rate', eq='#70']
    Robs1=rf-crf;
    [name='Foreing Interest Rate', eq='#71']
    Robs2=rf-crf;
end;
        
%-------------------------------------------------------------------------
% 4. Computation
%-------------------------------------------------------------------------
    
shocks;
    var atshk = 1;
    var anshk = 1;
    var sshk = 1;
    var ganshk = 1;
    var gatshk = 1;
    var mushk = 1;
    var nushk = 1;
    var epsshk = 1;
end;


%-------------------------------------------------------------------------
% 5. Simulations
%-------------------------------------------------------------------------
% 
%resid;
%steady;
%check;
%stoch_simul(order=1,irf=40,noprint,nomoments) TB_Y logQ logY logC logI kt kn ct cn;
%MODEL_DIAGNOSTICS;

%-------------------------------------------------------------------------
% 6. Estimation
%-------------------------------------------------------------------------
% 6.1 Priors
%-------------------------------------------------------------------------
% 
estimated_params;
           cgamma,2,1,10,gamma_pdf,2,0.1;
           calphton,1.3,1,1.5,normal_pdf,1.3,0.05;
           comegat,2.1,1.1,5,gamma_pdf,2,0.2;
           comegan,2.1,1.1,5,gamma_pdf,2,0.2;
           czeta,0.57,0.001,0.999,beta_pdf,0.62,0.01;
           cphit,40,0,100,gamma_pdf,5,4;
           cphin,40,0,100,gamma_pdf,5,4;
           csigma,0.5036,0,10,gamma_pdf,1,0.2;
           cvsgan,0.1,0.001,20,inv_gamma_pdf,0.1,2; 
           cvsgat,0.1,0.001,20,inv_gamma_pdf,0.1,2;
           cvsgv,0.1,0.001,20,inv_gamma_pdf,0.1,2;
           cvsmu,0.1,0.001,20,inv_gamma_pdf,0.1,2;
           cvsnu,0.1,0.001,20,inv_gamma_pdf,0.1,2;
           cvsat,0.1,0.001,20,inv_gamma_pdf,0.1,2;
           cvsan,0.1,0.001,20,inv_gamma_pdf,0.1,2;          
           cvseps,0.1,0.001,20,inv_gamma_pdf,0.1,2;
           cvrgan,0.5,0.001,0.999,beta_pdf,0.5,0.15;
           cvrgat,0.5,0.001,0.999,beta_pdf,0.5,0.15;
           cvrgv,0.5,0.001,0.999,beta_pdf,0.5,0.15;
           cvrmu,0.5,0.001,0.999,beta_pdf,0.5,0.15;
           cvrnu,0.5,0.001,0.999,beta_pdf,0.5,0.15;
           cvran,0.5,0.001,0.999,beta_pdf,0.5,0.15;
           cvrat,0.9,0.001,0.999,beta_pdf,0.5,0.15;
           cvreps,0.5,0.001,0.999,beta_pdf,0.5,0.17;

           stderr DlogPA, 0.01,  0.001,  9.000,  inv_gamma_pdf,  0.01,  0.0001;
           stderr DlogYN_NN, 0.01,  0.001,  9.000,  inv_gamma_pdf,  0.01,  .005;
           stderr DlogYT_NT, 0.01,  0.001,  9.000,  inv_gamma_pdf,  0.01,  0.005;
           stderr Robs1, 0.01,  0.001,  9.000,  inv_gamma_pdf,  0.01,  0.01;
           stderr Robs2, 0.01,  0.001,  9.000,  inv_gamma_pdf,  0.01,  0.01;

end;

%-------------------------------------------------------------------------
% 6.2 Observables
%-------------------------------------------------------------------------
varobs DlogYT_NT DlogYN_NN DlogP DlogPA C_Y I_Y N Robs1 Robs2; 

options_.conf_sig = 0.68;

%-------------------------------------------------------------------------
% 6.3 Estimation Options
%-------------------------------------------------------------------------
estimation(datafile='../data/EstimatiON.xlsx',
xls_sheet=DATAQ_estimatiON87,xls_range=B1:J117,presample=1,optim=('TolFun',1e-3,'MaxIter',1000,'Algorithm','active-set'),
order=1,filtered_vars,smoother,cova_compute=1,nobs=116,
%mode_check,
bayesian_irf,     
mode_file=soetnt_mode, 
forecast=12,
mh_jscale = 0.36,
conditional_variance_decomposition=[1 4 16],
mode_compute=1,
first_obs=1,prior_trunc=0,lyapunov=doubling,
mh_replic=300000,
mh_nblocks=2,
prefilter=0) DlogYT_NT DlogYN_NN DlogP C_Y I_Y N Robs1 Robs2;

shock_groups(name=G1);
'Foreign Rate'=mushk;
Government=sshk;
Discount=nushk;
'Temp TFP in T'=atshk; 
'Perm TFP in T'=gatshk;
'Temp TFP in N'=anshk; 
'Perm TFP in N'=ganshk;
'Labour'=epsshk;
end;

%shock_decomposition (
%use_shock_groups = G1,
%parameter_set    = posterior_mode) 
%DlogYT_NT DlogYN_NN logQ DlogP C_Y I_Y N TB_Y; 

%-------------------------------------------------------------------------
% 7.1 Plots
%-------------------------------------------------------------------------

%trace_plot(options_,M_,estim_params_,'PosteriorDensity',1);
%trace_plot(options_,M_,estim_params_,'StructuralShock',1,'gatshk');
%trace_plot(options_,M_,estim_params_,'StructuralShock',1,'atshk');

%-------------------------------------------------------------------------
% 7.2 In Sample Fit
%-------------------------------------------------------------------------
ObsVars=cellstr(options_.varobs);
dy=length(ObsVars);

[xlsData,xlsInfo]=xlsread('../data/EstimatiON.xlsx','DATAQ_estimatiON87','B1:J117');

for i = 1 : dy
    index=find(ismember(xlsInfo(1,:),ObsVars{i}));
    ObsVarsIndex(1,i)=index;
end
xlsData1=xlsData(2:end,ObsVarsIndex);
xlsData2=xlsData1;

T=size(xlsData2,1);
FittedData=zeros(T,dy);

for i = 1 : dy
    eval(['TermA=oo_.FilteredVariables.',ObsVars{i},'(2:end);'])
    FittedData(:,i)=TermA;
end

xxx=1:T;
figure('name','Fit')
orient landscape
for i = 1 : length(ObsVars)
    subplot(3,4,i)
    title(ObsVars{i})
    plot(xxx,xlsData2(:,i),'-b',xxx,eval(['oo_.FilteredVariables.',ObsVars{i},'(2:end);']),'--r','LineWidth',2)
    axis tight
    title(ObsVars{i})
end

%-------------------------------------------------------------------------
%8. Write results to latex
%-------------------------------------------------------------------------

%write_latex_definitions;
%write_latex_dynamic_model;
%write_latex_parameter_table;
%write_latex_prior_table;
%collect_latex_files; 
