function simOutputs = ...
    extract_simulation_paths(varInfo,allVarMnems,xSim,nPreShockPeriods)

%% UNPACK AND ANALYSE INPUTS
% varinfo is a cell array with 3 columns:
% 1. Mnemonic of variable as it appears in the model
% 2. Transformation type:
%   - logLevel100: apply appropriate trend and compute 100*log level
% 3. Transform info: 
%   - depends on transform type. For logLevel100, 'N' or 'T' specify the
%   relevant trends to apply.
varMnems = varInfo(:,1);
transformTypes = varInfo(:,2);
transformInfo = varInfo(:,3);
nVars = size(varMnems,1);

%% COMPUTE TRENDS THAT WILL BE USED IN ALL TRANSFORMS
% These are the lagged levels of productivity in the T and N sectors
[XTlagSimPath,gatSimPath] = ...
    compute_lag_productivity_level('gat',allVarMnems,xSim,nPreShockPeriods);
gatBGPath = gatSimPath(1)*ones(1,size(gatSimPath,2));
XTBGPath = cumprod(gatBGPath);
XTlagBGPath = XTBGPath(2:end);
XTlagBGPath(end+1) = XTlagBGPath(end);

[XNlagSimPath,ganSimPath] = ...
    compute_lag_productivity_level('gan',allVarMnems,xSim,nPreShockPeriods);
ganBGPath = ganSimPath(1)*ones(1,size(ganSimPath,2));
XNBGPath = cumprod(ganBGPath);
XNlagBGPath = XNBGPath(2:end);
XNlagBGPath(end+1) = XNlagBGPath(end);


%% INITIALISE OUTPUTS
simOutputs = struct;

%% LOOP OVER VARIABLES AND GATHER SIMULATION PATHS
for iVar = 1:nVars
    iMnem = varMnems{iVar};
    iTransform = transformTypes{iVar};
    iTransformInfo = transformInfo{iVar};
    switch iTransform
        case 'logLevel100'
            switch iTransformInfo
                case 'N'
                    [iSimPath,iBGPath] = ...
                        create_100log_levels_subfun(iMnem,...
                        allVarMnems,xSim,XNlagBGPath,...
                        XNlagSimPath,nPreShockPeriods);
                case 'T'
                    [iSimPath,iBGPath] = ...
                        create_100log_levels_subfun(iMnem,...
                        allVarMnems,xSim,XTlagBGPath,...
                        XTlagSimPath,nPreShockPeriods);
                case 'ToverN'
                    [iSimPath,iBGPath] = ...
                        create_100log_levels_subfun(iMnem,...
                        allVarMnems,xSim,XTlagBGPath./XNlagBGPath,...
                        XTlagSimPath./XNlagSimPath,nPreShockPeriods);
                otherwise
                    error('Transform approach not supported.');
            end
        case 'logLevel100noTrend'
             iLevel = get_paths(iMnem,allVarMnems,xSim,nPreShockPeriods);
             iBGPlevel = iLevel(1)*ones(1,size(iLevel,2));
             iSimPath = 100*log(iLevel);
             iBGPath = 100*log(iBGPlevel);
        case 'logLevel100devFromTrend'
             iLevel = get_paths(iMnem,allVarMnems,xSim,nPreShockPeriods);
             iBGPlevel = iLevel(1)*ones(1,size(iLevel,2));
             iSimPath = 100*log(iLevel) - 100*log(iBGPlevel);
             iBGPath = 0*iBGPath;
        case 'TBratio'
            selectedPaths = ...
                get_paths(iTransformInfo,allVarMnems,xSim,nPreShockPeriods);
            yTsimPath = selectedPaths(1,:);
            yNsimPath = selectedPaths(2,:);
            tbSimPath = selectedPaths(3,:);
            pSimPath = selectedPaths(4,:);
            iSimPath = 100*tbSimPath./(yTsimPath + pSimPath.*yNsimPath);
            iBGPath = iSimPath(1)*ones(1,size(iSimPath,2));
        case 'TBproxy'
            selectedPaths = ...
                get_paths(iTransformInfo,allVarMnems,xSim,nPreShockPeriods);
            yTsimPath = selectedPaths(1,:);
            yNsimPath = selectedPaths(2,:);
            ctSimPath = selectedPaths(3,:);
            pSimPath = selectedPaths(4,:);
            iSimPath = 100*(yTsimPath-ctSimPath)./...
                (yTsimPath + pSimPath.*yNsimPath);
            iBGPath = iSimPath(1)*ones(1,size(iSimPath,2));
        case 'TBproxyDevFromTrend'
            selectedPaths = ...
                get_paths(iTransformInfo,allVarMnems,xSim,nPreShockPeriods);
            yTsimPath = selectedPaths(1,:);
            yNsimPath = selectedPaths(2,:);
            ctSimPath = selectedPaths(3,:);
            pSimPath = selectedPaths(4,:);
            iSimPath = 100*(yTsimPath-ctSimPath)./...
                (yTsimPath + pSimPath.*yNsimPath);
            iBGPath = iSimPath(1)*ones(1,size(iSimPath,2));
            iSimPath = iSimPath - iBGPath;
            iBGPath = 0*iBGPath;
        case 'TBmodel_y'
            selectedPaths = ...
                get_paths(iTransformInfo,allVarMnems,xSim,nPreShockPeriods);
            yTsimPath = selectedPaths(1,:);
            yNsimPath = selectedPaths(2,:);
            ctSimPath = selectedPaths(3,:);
            ivtSimPath = selectedPaths(4,:);
            pSimPath = selectedPaths(5,:);
            iSimPath = 100*(yTsimPath-ctSimPath-ivtSimPath)./...
                (yTsimPath + pSimPath.*yNsimPath);
            iBGPath = iSimPath(1)*ones(1,size(iSimPath,2));
        case 'ChainLinked'
            iPaths = ...
                get_paths(iTransformInfo,allVarMnems,xSim,nPreShockPeriods);
            itSimPath = iPaths(1,:);
            inSimPath = iPaths(2,:);
            ipSimPath = iPaths(3,:);
            omegaTinit = ...
                itSimPath(1)/(itSimPath(1) + ipSimPath(1)*inSimPath(1));
            DlogitPath = [log(gatSimPath(1)),...
                log(itSimPath(2:end).*gatSimPath(2:end)./itSimPath(1:end-1))] ;
            DloginPath = [log(ganSimPath(1)),...
                log(inSimPath(2:end).*ganSimPath(2:end)./inSimPath(1:end-1))];
            [~,iSimLevel] = compute_chain_linked_GDP(DlogitPath,...
                DloginPath,ipSimPath,XTlagSimPath,XNlagSimPath,omegaTinit);
            % BGP is without shock
            itBGPath = itSimPath(1)*ones(1,size(itSimPath,2));
            inBGPath = inSimPath(1)*ones(1,size(inSimPath,2));
            ipBGPath = ipSimPath(1)*ones(1,size(ipSimPath,2));
            DlogitBGPath = [log(gatBGPath(1)),...
                log(itBGPath(2:end).*gatBGPath(2:end)./itBGPath(1:end-1))] ;
            DloginBGPath = [log(ganBGPath(1)),...
                log(inBGPath(2:end).*ganBGPath(2:end)./inBGPath(1:end-1))];
            [~,iBGlevel] = compute_chain_linked_GDP(DlogitBGPath,...
                DloginBGPath,ipBGPath,XTlagBGPath,XNlagBGPath,omegaTinit);
            iSimPath = 100*log(iSimLevel);
            iBGPath = 100*log(iBGlevel);
	   case 'RatioToOutput'
           selectedPaths = ...
               get_paths(iTransformInfo,allVarMnems,xSim,nPreShockPeriods);
           yTsimPath = selectedPaths(1,:);
           yNsimPath = selectedPaths(2,:);
           pSimPath = selectedPaths(3,:);
           pcSimPath = selectedPaths(4,:);
           ivSimPath = selectedPaths(5,:);
           iSimPath = 100*(pcSimPath.*ivSimPath)./...
               (yTsimPath + pSimPath.*yNsimPath);
           iBGPath = iSimPath(1)*ones(1,size(iSimPath,2));
        case 'RateDifference'
            iPaths = get_paths(iTransformInfo,allVarMnems,...
                    xSim,nPreShockPeriods);
            lrhSimPath = iPaths(1,:);
            lrfSimPath = iPaths(2,:);
            iSimPath = 100*(lrhSimPath - lrfSimPath);
            iBGPath = iSimPath(1)*ones(1,size(iSimPath,2));
        case 'times100'
            iLevel = get_paths(iTransformInfo,allVarMnems,xSim,nPreShockPeriods);
            iBGPlevel = iLevel(1)*ones(1,size(iLevel,2));
            iSimPath = 100*iLevel;
            iBGPath = 100*iBGPlevel;
        case 'minus1times400'
            iLevel = get_paths(iTransformInfo,allVarMnems,xSim,nPreShockPeriods);
            iBGPlevel = iLevel(1)*ones(1,size(iLevel,2));
            iSimPath = 400*(iLevel-1);
            iBGPath = 400*(iBGPlevel-1);
        case 'AverageLogLevel100'
            selectedPaths = ...
                get_paths(iTransformInfo,allVarMnems,xSim,nPreShockPeriods);
            wtPath = selectedPaths(1,:);
            wnPath = selectedPaths(2,:);
            ntPath = selectedPaths(3,:);
            nnPath = selectedPaths(4,:);
            iSimPath = ...
                100*log((wtPath.*ntPath+wnPath.*nnPath)./(ntPath+nnPath));
            iBGPath = iSimPath(1)*ones(1,size(iLevel,2));
        otherwise 
            error('Transform approach not supported.');
    end
    iMarginal = iSimPath - iBGPath;
    % Store results
    simOutputs.(iMnem).BGPath = iBGPath;
    simOutputs.(iMnem).simPath = iSimPath;
    simOutputs.(iMnem).marginal = iMarginal;
end

end

%% SUB-FUNCTIONS TO EXTRACT BANDS
function [simPath,BGPath] = ...
            create_100log_levels_subfun(iMnem,...
            allVarMnems,xSim,XNlagBGPath,XNlagSimPath,...
            nPreShockPeriods)

[simPath,BGPath] = create_100log_levels(iMnem,...
                        allVarMnems,xSim,XNlagBGPath,XNlagSimPath,...
                        nPreShockPeriods);

end