% Script to extract simulation outputs and compare to data in a table.

%% PATH AND WORKSPACE MANAGEMENT
tidyUpAndSetPath;
startTime = clock;

%% OPTIONS
estimationDataFile = [dataFolder 'selectedDataSeries.xlsx'];
saveTable = true;
% De-trending approach
detrendingInfo = struct;
periodZero = 78; % June 2016 is row 79 in s/sheet (-1 to account for removal of header)
detrendingInfo.detrendEndDate = periodZero;
detrendingInfo.detrendStartDate = 13; 
detrendingInfo.GFCdummyStartDate = 53;
detrendingInfo.detrendType = 'preferred';
% Options for table format
tableHorizons = [6; 12];
tabNumFormat = '%5.1f'; 
nTableHorizons = size(tableHorizons);
bottomTableDivider = 6;
% Variables to compare
varMnems = {'yt';'yn';'nt';'nn';'ct';'cn'; % Sectoral variables
    'GDP'; 'c' ; 'iv'; 'modelTB_y'; 'wAvg' % Aggregate variables
    };
varNames = {'Tradable output';...
    'Non-tradable output';...
    'Tradable sector hours';...
    'Non-tradable sector hours';...
    'Tradable consumption';...
    'Non-tradable consumption';...
    'GDP';...
    'Total consumption';...
    'Total investment';...
    'Tradable net export ratio';...
    'Average real wage'};

% Specify information about trends for each variable of interest
varInfo = {'yt', 'logLevel100', 'T';
           'yn', 'logLevel100', 'N';
           'ct', 'logLevel100', 'T';
           'cn', 'logLevel100', 'N';
           'p', 'logLevel100', 'ToverN';
           'tb_y','TBratio', {'yt';'yn';'tb';'p'};
           'GDP', 'ChainLinked', {'yt';'yn';'p'};
           'c', 'ChainLinked', {'ct';'cn';'p'};
           'iv', 'ChainLinked', {'ivt';'ivn';'p'};
           'I_Y', 'RatioToOutput', {'yt';'yn';'p';'pc';'iv'};
           'nn', 'logLevel100noTrend', '';
           'nt', 'logLevel100noTrend', '';
           'n', 'logLevel100noTrend', '';
           'modelTB_y','TBproxy',{'yt';'yn';'ct';'ivt';'p'}
            'wAvg','AverageLogLevel100',{'wt';'wn';'nt';'nn'}};

%% LOAD DATA
[data,dataNames] = xlsread(estimationDataFile,'PlotsLong','B1:L93');
[~,dateStrings] = xlsread(estimationDataFile,'PlotsLong','A2:A93');
detrendedSeries = extract_full_sample_detrended_data(data,...
        dataNames',varMnems,detrendingInfo);

%% LOAD SIMULATION OUTPUT
resultsFileName = [resultsFolder 'BrexitSimulation.mat'];
load(resultsFileName,'xSim','endogVarNames');

%% DO THE DATA EXTRACTION
nPreShockPeriods = periodZero - 1; 
simOutputs = ...
    extract_simulation_paths(varInfo,endogVarNames,xSim,nPreShockPeriods);

%% SET UP TEX INFO
nVars = size(varMnems,1);
nLines = nVars + 12;
tableText = cell(nLines,1);
iLine = 1;
texText{iLine,1} = '\begin{table}[h]';
iLine = iLine+1;
texText{iLine,1} = '\centering';
iLine = iLine+1;
texText{iLine,1} = '\begin{tabular}{l|ccc|ccc}';
iLine = iLine+1;
texText{iLine,1} = '\hline \hline';
iLine = iLine+1;
texText{iLine,1} = ['& \multicolumn{3}{c|}{' num2str(tableHorizons(1)) ' quarter horizon} & ',...
    '\multicolumn{3}{c}{' num2str(tableHorizons(2)) ' quarter horizon} \\'];
iLine = iLine+1;
texText{iLine,1} = ...
    'Sectoral variables & Simulation & Data & Ratio & Simulation & Data & Ratio \\';
iLine = iLine+1;
texText{iLine,1} = '\hline';

%% BUILD TABLE STRINGS
anticipationHorizon = periodZero:size(data,1);
for iVar = 1:nVars
    iVarMnem = varMnems{iVar};
    renormalisedResidual = ...
        detrendedSeries.(iVarMnem).residual(anticipationHorizon) - ...
        detrendedSeries.(iVarMnem).residual(periodZero);

	iSimPath = simOutputs.(iVarMnem).marginal(anticipationHorizon);
    tableString = [varNames{iVar} ' & '  ...
        num2str(iSimPath(tableHorizons(1)+1),tabNumFormat)  ' & ' ...
        num2str(renormalisedResidual(tableHorizons(1)+1),tabNumFormat) ' & ' ...
        num2str(iSimPath(tableHorizons(1)+1)/renormalisedResidual(tableHorizons(1)+1),tabNumFormat) '& ' ...
        num2str(iSimPath(tableHorizons(2)+1),tabNumFormat)  ' & ' ...
        num2str(renormalisedResidual(tableHorizons(2)+1),tabNumFormat) ' & '  ...
        num2str(iSimPath(tableHorizons(2)+1)/renormalisedResidual(tableHorizons(2)+1),tabNumFormat) ' \\ '];
    disp(tableString);  
    iLine = iLine+1;
    texText{iLine,1} = tableString;
    if iVar == bottomTableDivider 
        iLine = iLine+1;
        texText{iLine,1} = '\hline';
        iLine = iLine+1;
        texText{iLine,1} = ['& \multicolumn{3}{c|}{' num2str(tableHorizons(1)) ' quarter horizon} & ',...
            '\multicolumn{3}{c}{' num2str(tableHorizons(2)) ' quarter horizon} \\'];
        iLine = iLine+1;
        texText{iLine,1} = ...
            'Aggregate variables & Simulation & Data & Ratio & Simulation & Data & Ratio \\';
        iLine = iLine+1;
        texText{iLine,1} = '\hline';
    end
end

%% FINALISE TABLE
iLine = iLine+1;
texText{iLine,1} = '\hline';
iLine = iLine+1;
texText{iLine,1} = '\end{tabular}';
iLine = iLine+1;
texText{iLine,1} = '\caption{Comparison of simulation versus data}';
iLine = iLine+1;
texText{iLine,1} = ['\label{simVsData}'];
iLine = iLine+1;
texText{iLine,1} = '\end{table}';

%% SAVE TABLE IF REQUIRED
if saveTable
    texFileName = [figureFolder 'simVsDataTable.tex'];
    nLines = size(texText,1);
    try
        fileHandle = fopen(texFileName,'wt');
        for iLine = 1:nLines
            textToWrite = texText{iLine,1};
            fprintf(fileHandle,'%s',textToWrite);
            fprintf(fileHandle,'\n');
        end
        fclose(fileHandle);
    catch
        error('There was a problem in writing the TeX file...');
    end
end

%% DISPLAY TOTAL COMPUTATION TIME
finishTime = clock;
disp('*********************************************************');
disp('TOTAL COMPUTING TIME FOR ALL VARIANTS:');
compute_and_display_elapsed_time(startTime,finishTime);
    