% Script to extract simulation outputs and compare to data in a table.

%% PATH AND WORKSPACE MANAGEMENT
tidyUpAndSetPath;
startTime = clock;

%% OPTIONS
estimationDataFile = [dataFolder 'selectedDataSeries.xlsx'];
saveTable = true;
% De-trending approach
detrendingInfo = struct;
periodZero = 78; % June 2016 is row 79 in s/sheet (-1 to account for removal of header)
detrendingInfo.detrendEndDate = periodZero;
% Options for table format
tableHorizon = 12;
tabNumFormat = '%5.1f'; 
nTableHorizons = size(tableHorizon);
bottomTableDivider = 6;
% Variables to compare
varMnems = {'yt';'yn';'nt';'nn';'ct';'cn'; % Sectoral variables
    'GDP'; 'c' ; 'iv'; 'modelTB_y'; 'wAvg' % Aggregate variables
    };
varNames = {'Tradable output';...
    'Non-tradable output';...
    'Tradable sector hours';...
    'Non-tradable sector hours';...
    'Tradable consumption';...
    'Non-tradable consumption';...
    'GDP';...
    'Total consumption';...
    'Total investment';...
    'Tradable net export ratio';...
    'Average real wage'};

% Specify information about trends for each variable of interest
varInfo = {'yt', 'logLevel100', 'T';
           'yn', 'logLevel100', 'N';
           'ct', 'logLevel100', 'T';
           'cn', 'logLevel100', 'N';
           'p', 'logLevel100', 'ToverN';
           'tb_y','TBratio', {'yt';'yn';'tb';'p'};
           'GDP', 'ChainLinked', {'yt';'yn';'p'};
           'c', 'ChainLinked', {'ct';'cn';'p'};
           'iv', 'ChainLinked', {'ivt';'ivn';'p'};
           'I_Y', 'RatioToOutput', {'yt';'yn';'p';'pc';'iv'};
           'nn', 'logLevel100noTrend', '';
           'nt', 'logLevel100noTrend', '';
           'n', 'logLevel100noTrend', '';
           'modelTB_y','TBproxy',{'yt';'yn';'ct';'ivt';'p'};
            'wAvg','AverageLogLevel100',{'wt';'wn';'nt';'nn'}};
        
%% LOAD DATA
[data,dataNames] = xlsread(estimationDataFile,'PlotsLong','B1:L93');
[~,dateStrings] = xlsread(estimationDataFile,'PlotsLong','A2:A93');

%% DETREND ACCORDING TO ALTERNATIVE ASSUMPTIONS
detrendingInfo.detrendStartDate = 13;
detrendingInfo.GFCdummyStartDate = 53; 
detrendingInfo.detrendType = 'preferred';
detrendedSeriesBaseline = extract_full_sample_detrended_data(data,...
        dataNames',varMnems,detrendingInfo);

detrendingInfo.detrendStartDate = 1;    
detrendingInfo.detrendType = 'hamilton';
detrendedSeriesHamilton = extract_full_sample_detrended_data(data,...
        dataNames',varMnems,detrendingInfo);

detrendingInfo.detrendStartDate = 1;
detrendingInfo.detrendType = 'linear';
detrendedSeriesLinear = extract_full_sample_detrended_data(data,...
        dataNames',varMnems,detrendingInfo);

detrendingInfo.detrendStartDate = 1;
detrendingInfo.detrendType = 'HP';
detrendedSeriesHPfilter = extract_full_sample_detrended_data(data,...
        dataNames',varMnems,detrendingInfo);

%% LOAD SIMULATION OUTPUT
resultsFileName = [resultsFolder 'BrexitSimulation.mat'];
load(resultsFileName,'xSim','endogVarNames');

%% DO THE DATA EXTRACTION
nPreShockPeriods = periodZero - 1; 
simOutputs = ...
    extract_simulation_paths(varInfo,endogVarNames,xSim,nPreShockPeriods);

%% SET UP 
nVars = size(varMnems,1);
nLines = nVars + 7;
tableText = cell(nLines,1);
iLine = 1;
texText{iLine,1} = '\begin{table}[h]';
iLine = iLine+1;
texText{iLine,1} = '\centering';
iLine = iLine+1;
texText{iLine,1} = '\begin{tabular}{l|c|cccc}';
iLine = iLine+1;
texText{iLine,1} = '\hline \hline';
iLine = iLine+1;
texText{iLine,1} = ['& & \multicolumn{4}{c}{' num2str(tableHorizon) ' quarter ratios} \\'];
iLine = iLine+1;
texText{iLine,1} = ...
    'Variable & Simulation & Preferred & Linear & Hamilton & HP \\';
iLine = iLine+1;
texText{iLine,1} = '\hline';

%% BUILD TABLE STRINGS
anticipationHorizon = periodZero:size(data,1);
for iVar = 1:nVars
    iVarMnem = varMnems{iVar};
    renormalisedResidualBaseline = ...
        detrendedSeriesBaseline.(iVarMnem).residual(anticipationHorizon) - ...
        detrendedSeriesBaseline.(iVarMnem).residual(periodZero);
    
    renormalisedResidualHamilton = ...
        detrendedSeriesHamilton.(iVarMnem).residual(anticipationHorizon) - ...
        detrendedSeriesHamilton.(iVarMnem).residual(periodZero);

    renormalisedResidualLinear = ...
        detrendedSeriesLinear.(iVarMnem).residual(anticipationHorizon) - ...
        detrendedSeriesLinear.(iVarMnem).residual(periodZero);
    
    renormalisedResidualHPfilter = ...
        detrendedSeriesHPfilter.(iVarMnem).residual(anticipationHorizon) - ...
        detrendedSeriesHPfilter.(iVarMnem).residual(periodZero);

	iSimPath = simOutputs.(iVarMnem).marginal(anticipationHorizon);
    
    tableString = [varNames{iVar} ' & '  ...
        num2str(iSimPath(tableHorizon+1),tabNumFormat)  ' & ' ...
        num2str(iSimPath(tableHorizon+1)/renormalisedResidualBaseline(tableHorizon+1),tabNumFormat) '& ' ...
        num2str(iSimPath(tableHorizon+1)/renormalisedResidualLinear(tableHorizon+1),tabNumFormat) '& ' ...
        num2str(iSimPath(tableHorizon+1)/renormalisedResidualHamilton(tableHorizon+1),tabNumFormat) '& ' ...
        num2str(iSimPath(tableHorizon+1)/renormalisedResidualHPfilter(tableHorizon+1),tabNumFormat) ' \\ '];
    disp(tableString);  
    iLine = iLine+1;
    texText{iLine,1} = tableString;
    if iVar == bottomTableDivider 
        iLine = iLine+1;
        texText{iLine,1} = '\hline';
    end
end

%% FINALISE TABLE
iLine = iLine+1;
texText{iLine,1} = '\hline';
iLine = iLine+1;
texText{iLine,1} = '\end{tabular}';
iLine = iLine+1;
texText{iLine,1} = '\caption{Comparison of simulation versus data under alternative detrending methods}';
iLine = iLine+1;
texText{iLine,1} = ['\label{simVsData_Robustness}'];
iLine = iLine+1;
texText{iLine,1} = '\end{table}';

%% SAVE TABLE IF REQUIRED
if saveTable
    texFileName = [figureFolder 'simVsDataTableRobustness.tex'];
    nLines = size(texText,1);
    try
        fileHandle = fopen(texFileName,'wt');
        for iLine = 1:nLines
            textToWrite = texText{iLine,1};
            fprintf(fileHandle,'%s',textToWrite);
            fprintf(fileHandle,'\n');
        end
        fclose(fileHandle);
    catch
        error('There was a problem in writing the TeX file...');
    end
end

%% DISPLAY TOTAL COMPUTATION TIME
finishTime = clock;
disp('*********************************************************');
disp('TOTAL COMPUTING TIME FOR ALL VARIANTS:');
compute_and_display_elapsed_time(startTime,finishTime);
    